yt.units.unit_object.Unit.lseries — The yt Project 3.2-dev documentation

# yt.units.unit_object.Unit.lseries

`Unit.` `lseries`(x=None, x0=0, dir='+', logx=None)

  Wrapper for series yielding an iterator of the terms of the series.

  Note: an infinite series will yield an infinite iterator. The following, for exaxmple, will never terminate. It will just keep printing terms of the sin(x) series:

      for term in sin(x).lseries(x):
          print term

  The advantage of lseries() over nseries() is that many times you are just interested in the next term in the series (i.e. the first term for example), but you don’t know how many you should ask for in nseries() using the “n” parameter.

  See also nseries().